![Bump version](https://github.com/jupyter-naas/drivers/workflows/Bump%20version/badge.svg)
![GitHub license](https://img.shields.io/github/license/jupyter-naas/drivers)
![Test Python package](https://github.com/jupyter-naas/drivers/workflows/Test%20Python%20package/badge.svg)
![Upload Python Package](https://github.com/jupyter-naas/drivers/workflows/Upload%20Python%20Package/badge.svg)
![codecov](https://codecov.io/gh/jupyter-naas/drivers/branch/master/graph/badge.svg?token=IUF0AKYEB0)
![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=jupyter-naas_drivers&metric=sqale_rating)](https://sonarcloud.io/dashboard?id=jupyter-naas_naas)
<a href="#badge">
  <img alt="semantic-release" src="https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg">
</a>
<a href="http://commitizen.github.io/cz-cli/"><img alt="Commitizen friendly" src="https://img.shields.io/badge/commitizen-friendly-brightgreen.svg"></a>
![PyPI](https://img.shields.io/pypi/v/naas_drivers)

# Welcome to Naas Drivers 🏎

Simple formulas to build highly efficient scripts.<br>
You can check the documentation here: https://docs.naas.ai

## Low code philosophy

We came from excel with the conviction that Python is awesome and much more powerful.
But the number of lines you have to write in Python can be overwelming. <br>

So we created simple low code formulas that tech and non-tech people can use to facilitate integrations with third party tools.<br>

Simple formulas to interact with powerfull tools.<br>
Each driver returns a dataframe to get a strandardized output accross integrations.

## Issues
If you found a bug or need a new feature, please raise an issue.

## Install

`python -m pip install naas_drivers`

### Check lint

`python3 -m black naas` format better <br>
`python3 -m flake8 naas` check if any left error

### Publish

This auto publish on pypip by github action on main branch.

### Authors:
* [Jeremy Ravenel](https://github.com/jravenel)
* [Maxime Jublou](https://github.com/Dr0p42)
* [Martin Donadieu](https://github.com/riderx)
* [Florent Ravenel](https://github.com/FlorentLvr)

## Legal
### LinkedIn driver
This code is in no way affiliated with, authorized, maintained, sponsored or endorsed by Linkedin or any of its affiliates or subsidiaries. It uses an independent and unofficial API. Use at your own risk.
This project violates Linkedin's User Agreement Section 8.2, and because of this, Linkedin may (and will) temporarily or permanently ban your account. We are not responsible for your account being banned.
